# ezdmb

![ezdmb logo](https://github.com/justinmichaelvieira/ezdmb/raw/master/readme_images/logo_crop.png "ezdmb logo")

A dead-simple digital menu board display and configuration.  Engineered to be the simplest, cheapest, fastest way to get your menu to display on **any** tablet or computer. Engineered for user-friendliness, with a simple, basic, configuration interface that easily allows rotation of images and quick configuration.

![ezdmb UI](https://github.com/justinmichaelvieira/ezdmb/raw/master/readme_images/sample1.png "ezdmb UI")

## Installing and running ezdmb on Windows

1. [Download the install zip.](https://github.com/justinmichaelvieira/ezdmb/releases/latest/download/ezdmb_install.zip)
2. Extract the entire zip file to any folder.
3. Double click install.bat.
4. Once the installer completes, you can launch the app using the Start Menu (Start > Run ezdmb)

## Basic Operation

- On app start, both the Main (fullscreen) and Preview/Configuration windows are shown on the desktop.
- The Settings window can be closed with the "X" icon at top right of the window if further settings changes are not currently needed.
- The 'Esc' key is used to exit the application.
- Clicking or tapping the Main window and then pressing the 'o' key will reopen the Preview/Configuration window.

## Configuration

 "Edit Display Settings" in the "File" dropdown menu of the Settings window allows access to a settings window, which is used to:

- Add and remove content to display
- Rotation settings, to allow content to be changed in the Menu Board Display
![Display settings](https://github.com/justinmichaelvieira/ezdmb/raw/master/readme_images/sample2.png "Display settings")

![Settings window up close](https://github.com/justinmichaelvieira/ezdmb/raw/master/readme_images/sample3.png "Configuration window up close")

## Developer environment setups

[Windows and Ubuntu developer install scripts are available (useful if you want to do code updates)](https://github.com/justinmichaelvieira/ezdmb/raw/master//DEVELOPERS.md)
